/***********************************************************************
 *
 * EX_Error.h is the class to generate error messages 
 * 
 ***********************************************************************
 * License
 * (C) Copyright 2019 Falk Richter, falk.richter at yandex.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/ 

#include <stdio.h>
#include "EX_Error.h"

#define ERROR_REASON_LEN 255u
static char aszErrorReason[ERROR_REASON_LEN];


/* -------------------------------------------------------------------- */ 
/* Compose the error message and save it internally */
/* -------------------------------------------------------------------- */ 
void EX_vSetError(const char *pszErrorMessage, const char *pszFileName, sint32_T s32LineNumber) { 

  size_t ErrorReasonLen = ERROR_REASON_LEN;

  uint32_T u32StrLen = snprintf(aszErrorReason, ErrorReasonLen, "%s in: %s, line number: %d.", 
      pszErrorMessage, pszFileName, s32LineNumber);

  if (u32StrLen > ErrorReasonLen) {
    fprintf(stderr, "The error message could not be saved because it is longer than storage buffer!");
  } 
}


/* -------------------------------------------------------------------- */ 
/* Print the error reason to the standard error console */
/* -------------------------------------------------------------------- */ 
void EX_vPrintReason(void) {

  fprintf(stderr, "%s\n", aszErrorReason);

}

