/***********************************************************************
 * ME_LogFile.c
 *
 * Generates a logging file with all measurement results
 *
 ***********************************************************************
 * License
 * (C) Copyright 2019 Falk Richter, falk.richter at yandex.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/ 

#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/* error handling */
#include "EX_Error.h"
/* needed for the file name */
#include "PRJ_Settings.h" 
/* the own header */
#include "ME_LogFile.h"

FILE * FileId;

/* -------------------------------------------------------------------- */
/* open the logging file and write the header */
/* -------------------------------------------------------------------- */
bool_T ME_bStartLogFile(void) {

  struct tm * pstTime;
  time_t Seconds;
  char aszTimeStamp[80u];
  char aszLine[80u];

  /* fetch the time in seconds */
  time( &Seconds );
  /* convert into the time structure */
  pstTime = localtime( &Seconds );
  /* parse it into a string */
  strftime(aszTimeStamp, 80u,"Time: %d. %B %Y - %H:%M %S", pstTime);

  /* open the file and add the new content at the end of the file */
  FileId = fopen(PRJxSET_pszGetLogFileName(), "a+");

  /* check the success */
  if ( FileId == NULL ) {
    /* an error occurred - we through an exception */
    char aszErrorMsg[] = "Could not open the logging file"; 
    EX_vSetError(aszErrorMsg, __FILE__, __LINE__);
    return(FALSE);
  }

  /* generates a line around the time stamp */
  memset( (void *) aszLine, '-', 79u);

  /* terminate the line */
  aszLine[79u] = '\0';

  /* add the header to the logging file */
  fprintf( FileId, "%s\n", aszLine); 
  fprintf( FileId, "%s\n", aszTimeStamp);
  fprintf( FileId, "%s\n", aszLine);

  return(TRUE); 
} 


/* -------------------------------------------------------------------- */ 
/* add a line to the logging file */
/* -------------------------------------------------------------------- */
void ME_vAddLine(char * pszLine) {
  /* output to the console */
  fprintf( stdout, "%s\n", pszLine );
  /* print it into the logging file */
  fprintf( FileId, "%s\n", pszLine );
}


/* -------------------------------------------------------------------- */ 
/* close the logging file */
/* -------------------------------------------------------------------- */
void ME_vCloseLogFile(void) {
  /* print a last line break to have a spacing 
   * to the next measurement */
  fprintf(stdout,"\n"); 
  fprintf( FileId, "\n" );
  
  /* close the file stream */
  fclose(FileId);
} 

