/***********************************************************************
 *
 * PRJ_Settings.c is a structure with project global settings
 * 
 ***********************************************************************
 * License
 * (C) Copyright 2019 Falk Richter, falk.richter at yandex.com
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/ 

#include "PRJ_Settings.h" 

typedef struct {
  bool_T bVerboseMode;
  char * pszFileName;
  uint32_T u32TestTypes;
  uint32_T u32CacheSize;
  char * pszLogFileName;
} PRJxSET_stSettings_T;

static PRJxSET_stSettings_T mg_stPRJ_Settings;

/* -------------------------------------------------------------------- */
/* the initialization function */
/* -------------------------------------------------------------------- */
void PRJxSET_vInit(void) {
  /* set the name of the hard disc file */ 
  char aszFileName[] = "FileWriteReadTest.txt";
  /* set the name of the logging file */
  char aszLogFileName[] = "PerfTest.log";

  /* prepare the hard disk file */
  /* asked for the length (we are lazy) */
  size_t FileLen = strlen(aszFileName);
  /* reserve memory including the zero termination */
  mg_stPRJ_Settings.pszFileName = (char *) malloc(FileLen + 1u);
  /* copy the file name into the structure */
  strncpy(mg_stPRJ_Settings.pszFileName, aszFileName, FileLen);

  /* prepare the logging file */
  /* asked for the length (we are lazy) */
  FileLen = strlen(aszLogFileName);
  /* reserve memory including the zero termination */
  mg_stPRJ_Settings.pszLogFileName = (char *) malloc(FileLen + 1u);
  /* copy the file name into the structure */
  strncpy(mg_stPRJ_Settings.pszLogFileName, aszLogFileName, FileLen); 

  /* verbose mode is deactivated */
  mg_stPRJ_Settings.bVerboseMode = FALSE;

  /* all tests activated */
  mg_stPRJ_Settings.u32TestTypes = 7u;

  /* standard cache size is 256kB */
  mg_stPRJ_Settings.u32CacheSize = 256u; 
}


/* -------------------------------------------------------------------- */
/* set the verbose mode status */
/* -------------------------------------------------------------------- */
bool_T PRJxSET_bSetVerboseMode(bool_T bNewVerboseMode) {
  /* nothing to test here */
  mg_stPRJ_Settings.bVerboseMode = bNewVerboseMode;

  return(TRUE);
}


/* -------------------------------------------------------------------- */
/* get the verbose mode status */
/* -------------------------------------------------------------------- */
bool_T PRJxSET_bGetVerboseMode(void)
{
  return(mg_stPRJ_Settings.bVerboseMode);
}


/* -------------------------------------------------------------------- */
/* set the type of tests */
/* -------------------------------------------------------------------- */
bool_T  PRJxSET_bSetTestTypes(uint32_T u32NewTestTypes) {
  /* at the moment only values from 1 to 7 are allowed */
  if ( (u32NewTestTypes > 0) && (u32NewTestTypes < 8u) ) {
    /* copy the new test type */
    mg_stPRJ_Settings.u32TestTypes = u32NewTestTypes;
    return(TRUE);
  }
  return(FALSE);
}


/* -------------------------------------------------------------------- */
/* get the type of tests */
/* -------------------------------------------------------------------- */
uint32_T PRJxSET_u32GetTestTypes(void)
{
  return(mg_stPRJ_Settings.u32TestTypes);
}


/* -------------------------------------------------------------------- */
/* set the cache size */
/* -------------------------------------------------------------------- */
bool_T  PRJxSET_bSetCacheSize(uint32_T u32NewCacheSize) {

  switch(u32NewCacheSize) {
    case 64:   /*  64kBytes */
    case 128:  /* 128kBytes */
    case 256:  /* 256kBytes */
    case 512:  /* 512kBytes */
    case 1024: /*   1MByte  */
      {
	/* copy the cache size */
	mg_stPRJ_Settings.u32CacheSize = u32NewCacheSize;
	return(TRUE);
      }
    default:
      {
	/* unknown size */
	return(FALSE);
      } 
  }
}


/* -------------------------------------------------------------------- */
/* get the cache size */
/* -------------------------------------------------------------------- */
uint32_T PRJxSET_u32GetCacheSize(void)
{
  return(mg_stPRJ_Settings.u32CacheSize);
}


/* -------------------------------------------------------------------- */
/* get the name of the write/read test file */
/* -------------------------------------------------------------------- */
char * PRJxSET_pszGetFileName(void)
{
  return(mg_stPRJ_Settings.pszFileName);
}


/* -------------------------------------------------------------------- */
/* get the name of the logging file */
/* -------------------------------------------------------------------- */
char * PRJxSET_pszGetLogFileName(void)
{
  return(mg_stPRJ_Settings.pszLogFileName);
}

